/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent;

import org.onosproject.nemo.model.common.UserId;
import org.onosproject.nemo.model.common.UserName;
import org.onosproject.nemo.model.common.UserPassword;
import org.onosproject.nemo.model.common.UserRoleName;

/**
 * Representation of register user input.
 */
public interface RegisterUserInput {

    /**
     * Returns user's identifier.
     *
     * @return a unique ID for a user.
     */
    UserId getUserId();

    /**
     * Returns user's name.
     *
     * @return a user-visible and unique name for the user.
     */
    UserName getUserName();

    /**
     * Returns user's password.
     *
     * @return a password of a user.
     */
    UserPassword getUserPassword();

    /**
     * Returns user's role.
     *
     * @return a role of a user.
     */
    UserRoleName getUserRole();
}