/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.node.definitions;

import org.onosproject.nemo.model.common.NodeType;
import org.onosproject.nemo.model.object.property.definitions.PropertyDefinition;

import java.util.List;

/**
 * Single Node definition's information.
 */
public interface NodeDefinition {

    /**
     * Returns a unique node type for a kind of node.
     *
     * @return a unique node type
     */
    NodeType getNodeType();

    /**
     * Returns the primary key of YANG list type.
     *
     * @return the key
     */
    NodeDefinitionKey getKey();

    /**
     * Returns a description of the characteristic,
     * responsibility and purpose for a kind of property.
     *
     * @return a description of property
     */
    List<PropertyDefinition> getPropertyDefinitions();
}