/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.action.instance.parameter.values;

import java.util.Objects;

import com.google.common.base.MoreObjects;

/**
 * Key of IntValue.
 */
public class IntValueKey {

    private final long value;
    private final long order;

    /**
     * Creates an object from order and value.
     *
     * @param order order
     * @param value value
     */
    public IntValueKey(long order, long value) {
        this.order = order;
        this.value = value;
    }

    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public IntValueKey(IntValueKey source) {
        this.value = source.value;
        this.order = source.order;
    }

    /**
     * Returns the value of this instance.
     *
     * @return value
     */
    public long getValue() {
        return value;
    }

    /**
     * Returns order of the instance.
     *
     * @return order
     */
    public long getOrder() {
        return order;
    }

    @Override
    public int hashCode() {
        int prime = 31;
        int result = Objects.hashCode(value);
        return prime * result + Objects.hashCode(order);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        IntValueKey other = (IntValueKey) obj;
        return Objects.equals(value, other.value) &&
                Objects.equals(order, other.order);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("value", value)
                .add("order", order)
                .toString();
    }
}