/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.user;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;
import org.onosproject.nemo.model.common.UserRoleDescription;
import org.onosproject.nemo.model.common.UserRoleName;
import org.onosproject.nemo.model.user.roles.UserRole;
import org.onosproject.nemo.model.user.roles.UserRoleBuilder;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link UserRolesBuilder}.
 */
public class UserRolesBuilderTest {

    private static final String ROLES_ERROR_MSG = "user roles not set";
    private static final String NAME = "SomeName";
    private static final String OTHER_NAME = "OtherName";
    private static final String DESC = "SomeDescription";

    private List<UserRole> roleList;
    private List<UserRole> otherList;
    private UserRoles roles;
    private UserRoles copy;
    private UserRoles diff;
    private UserRoleDescription desc;
    private UserRoleName name;
    private UserRoleName otherName;
    private UserRole role;
    private UserRole otherRole;

    @Test
    public void buildUserRoleWithUserRoles() {
        roleList = new ArrayList<>();
        roles = new UserRolesBuilder()
                .userRoles(roleList)
                .build();
        assertEquals(ROLES_ERROR_MSG, roleList, roles.getUserRoles());
    }

    @Test
    public void fromUserRoleWithUserRoles() {
        roleList = new ArrayList<>();
        roles = new UserRolesBuilder()
                .userRoles(roleList)
                .build();
        copy = new UserRolesBuilder(roles).build();
        assertEquals(ROLES_ERROR_MSG, roleList, copy.getUserRoles());
    }

    @Test
    public void equality() {
        roleList = new ArrayList<>();
        roles = new UserRolesBuilder()
                .userRoles(roleList)
                .build();
        otherList = new ArrayList<>();
        otherList.add(null);
        copy = new UserRolesBuilder()
                .userRoles(roleList)
                .build();
        diff = new UserRolesBuilder()
                .userRoles(otherList)
                .build();
        new EqualsTester()
                .addEqualityGroup(roles, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }

    @Test
    public void equalityTwo() {
        name = new UserRoleName(NAME);
        otherName = new UserRoleName(OTHER_NAME);
        desc = new UserRoleDescription(DESC);
        role = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(name)
                .build();
        roleList = new ArrayList<>();
        roleList.add(role);
        roles = new UserRolesBuilder()
                .userRoles(roleList)
                .build();
        otherList = new ArrayList<>();
        otherRole = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(otherName)
                .build();
        otherList.add(otherRole);
        copy = new UserRolesBuilder()
                .userRoles(roleList)
                .build();
        diff = new UserRolesBuilder()
                .userRoles(otherList)
                .build();
        new EqualsTester()
                .addEqualityGroup(roles, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}