/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.user.roles;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.UserRoleDescription;
import org.onosproject.nemo.model.common.UserRoleName;

import com.google.common.testing.EqualsTester;
/**
 * Unit tests for {@link UserRoleBuilder}.
 */
public class UserRoleBuilderTest {

    private static final String NAME = "SomeName";
    private static final String OTHER_NAME = "OtherName";
    private static final String DESC = "SomeDescription";
    private static final String NAME_ERROR_MSG = "name not set";
    private static final String DESC_ERROR_MSG = "description not set";
    private static final String KEY_ERROR_MSG = "key not set";

    private UserRoleKey key;
    private UserRoleDescription desc;
    private UserRoleName name;
    private UserRoleName otherName;
    private UserRole role;
    private UserRole copy;
    private UserRole diff;

    @Test
    public void buildUserRoleWithUserRoleKey() {
        name = new UserRoleName(NAME);
        key = new UserRoleKey(name);
        desc = new UserRoleDescription(DESC);
        role = new UserRoleBuilder()
                .roleDescription(desc)
                .key(key)
                .build();
        assertEquals(NAME_ERROR_MSG, name, role.getRoleName());
        assertEquals(KEY_ERROR_MSG, key, role.getKey());
        assertEquals(DESC_ERROR_MSG, desc, role.getRoleDescription());
    }

    @Test
    public void buildUserRoleWithRoleName() {
        name = new UserRoleName(NAME);
        key = new UserRoleKey(name);
        desc = new UserRoleDescription(DESC);
        role = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(name)
                .build();
        assertEquals(NAME_ERROR_MSG, name, role.getRoleName());
        assertEquals(KEY_ERROR_MSG, key, role.getKey());
        assertEquals(DESC_ERROR_MSG, desc, role.getRoleDescription());
    }

    @Test
    public void fromUserRoleWithRoleKey() {
        name = new UserRoleName(NAME);
        key = new UserRoleKey(name);
        desc = new UserRoleDescription(DESC);
        role = new UserRoleBuilder()
                .roleDescription(desc)
                .key(key)
                .build();
        copy = new UserRoleBuilder(role).build();
        assertEquals(NAME_ERROR_MSG, name, copy.getRoleName());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
        assertEquals(DESC_ERROR_MSG, desc, copy.getRoleDescription());
    }

    @Test
    public void fromUserRoleWithRoleName() {
        name = new UserRoleName(NAME);
        key = new UserRoleKey(name);
        desc = new UserRoleDescription(DESC);
        role = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(name)
                .build();
        copy = new UserRoleBuilder(role).build();
        assertEquals(NAME_ERROR_MSG, name, copy.getRoleName());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
        assertEquals(DESC_ERROR_MSG, desc, copy.getRoleDescription());
    }

    @Test
    public void equality() {
        name = new UserRoleName(NAME);
        desc = new UserRoleDescription(DESC);
        role = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(name)
                .build();
        copy = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(name)
                .build();
        otherName = new UserRoleName(OTHER_NAME);
        diff = new UserRoleBuilder()
                .roleDescription(desc)
                .roleName(otherName)
                .build();
        new EqualsTester()
                .addEqualityGroup(role, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}